@@ -31,7 +31,11 @@
 #include <kseparator.h>
 #include <KStringHandler>
 
+#ifndef HAVE_NEPOMUK
+#include <KFileMetaDataWidget>
+#else
 #include <nepomuk2/filemetadatawidget.h>
+#endif
 
 #include <panels/places/placesitem.h>
 #include <panels/places/placesitemmodel.h>
@@ -101,13 +105,18 @@ InformationPanelContent::InformationPanelContent(QWidget* parent) :
     QFont font = m_nameLabel->font();
     font.setBold(true);
     m_nameLabel->setFont(font);
+    m_nameLabel->setTextFormat(Qt::PlainText);
     m_nameLabel->setAlignment(Qt::AlignHCenter);
     m_nameLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
 
     const bool previewsShown = InformationPanelSettings::previewsShown();
     m_preview->setVisible(previewsShown);
 
+#ifndef HAVE_NEPOMUK
+    m_metaDataWidget = new KFileMetaDataWidget(parent);
+#else
     m_metaDataWidget = new Nepomuk2::FileMetaDataWidget(parent);
+#endif
     m_metaDataWidget->setFont(KGlobalSettings::smallestReadableFont());
     m_metaDataWidget->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Minimum);
     connect(m_metaDataWidget, SIGNAL(urlActivated(KUrl)), this, SIGNAL(urlActivated(KUrl)));
